# -*- coding: utf-8 -*-


import os

import pungi.paths
from pungi.util import makedirs


"""
Changes to default paths:

* os/addons/$addon -> os/$addon
* $variant/source/tree/Packages/ -> $variant/source/SRPMS
* $variant/$arch/debug/tree/Packages/ -> $variant/$arch/debug
* $variant/optional/$arch/debug/tree/Packages/ -> $variant/optional/$arch/debug
* $variant-optional/$arch -> $variant/optional/$arch
"""


class LogPaths(pungi.paths.LogPaths):
    pass


class WorkPaths(pungi.paths.WorkPaths):
    pass


class ComposePaths(pungi.paths.ComposePaths):

    def topdir(self, arch=None, variant=None, create_dir=True, relative=False):
        """
        Examples:
            compose
            compose/Server/x86_64
        """
        if bool(arch) != bool(variant):
            raise TypeError("topdir(): either none or 2 arguments are expected")

        path = ""
        if not relative:
            path = os.path.join(self.compose.topdir, "compose")

        if arch or variant:
            if variant.type == "addon":
                return self.topdir(arch, variant.parent, create_dir=create_dir, relative=relative)
            if variant.type == "optional":
                # CHANGE: $variant-optional/$arch -> $variant/optional/$arch
                path = os.path.join(path, variant.parent.uid, "optional", arch)
            else:
                path = os.path.join(path, variant.uid, arch)
        if create_dir and not relative:
            makedirs(path)
        return path

    def tree_dir(self, arch, variant, create_dir=True, relative=False):
        """
        Examples:
            compose/Server/x86_64/os
            compose/Server-optional/x86_64/os
        """
        if arch == "src":
            arch = "source"

        if arch == "source":
            # CHANGE: $variant/source/tree/Packages/ -> $variant/source/SRPMS
            tree_dir = "SRPMS"
        else:
            # use 'os' dir due to historical reasons
            tree_dir = "os"

        path = os.path.join(self.topdir(arch, variant, create_dir=create_dir, relative=relative), tree_dir)
        if create_dir and not relative:
            makedirs(path)
        return path

    def packages(self, arch, variant, create_dir=True, relative=False):
        """
        Examples:
            compose/Server/x86_64/os/Packages
            compose/Server/x86_64/os/LoadBalancer
            compose/Server/optional/x86_64/os/Packages
        """
        if arch == "src":
            arch = "source"

        if arch == "source":
            path = self.tree_dir(arch, variant, create_dir=create_dir, relative=relative)
        elif variant.type == "addon":
            # CHANGE: os/addons/$addon -> os/$addon
            path = os.path.join(self.tree_dir(arch, variant, create_dir=create_dir, relative=relative), variant.id)
        else:
            path = os.path.join(self.tree_dir(arch, variant, create_dir=create_dir, relative=relative), "Packages")
        if create_dir and not relative:
            makedirs(path)
        return path

    def debug_tree(self, arch, variant, create_dir=True, relative=False):
        """
        Examples:
            compose/Server/x86_64/debug from x86_64/debug/tree
            compose/Server-optional/x86_64/debug from x86_64/debug/tree
        """
        return self.debug_topdir(arch, variant, create_dir, relative)

    def debug_repository(self, arch, variant, create_dir=True, relative=False):
        if arch == "src":
            arch = "source"
        if arch == "source":
            return None
        return self.debug_tree(arch, variant, create_dir, relative)

    def debug_packages(self, arch, variant, create_dir=True, relative=False):
        if arch == "src":
            arch = "source"
        if arch == "source":
            return None
        return self.debug_tree(arch, variant, create_dir, relative)
